@@ -588,6 +588,15 @@ void FullScreenFrame::keyPressEvent(QKeyEvent *e)
 
 void FullScreenFrame::showEvent(QShowEvent *e)
 {
+    // 显示后加载当前模式其他ratio的资源，预加载全屏另一种模式当前ratio的资源
+    if (m_calcUtil->displayMode() == GROUP_BY_CATEGORY) {
+        emit m_appsManager->loadOtherRatioIcon(GROUP_BY_CATEGORY);
+        emit m_appsManager->loadCurRationIcon(ALL_APPS);
+    } else {
+        emit m_appsManager->loadOtherRatioIcon(ALL_APPS);
+        emit m_appsManager->loadCurRationIcon(GROUP_BY_CATEGORY);
+    }
+
     m_delayHideTimer->stop();
     m_searchWidget->clearSearchContent();
 
@@ -758,11 +767,7 @@ bool FullScreenFrame::eventFilter(QObject *o, QEvent *e)
     // we filter some key events from LineEdit, to implements cursor move.
     if (o == m_searchWidget->edit()->lineEdit() && e->type() == QEvent::KeyPress) {
         QKeyEvent *keyPress = static_cast<QKeyEvent *>(e);
-        if (keyPress->key() == Qt::Key_Left || keyPress->key() == Qt::Key_Right) {
-            QKeyEvent *event = new QKeyEvent(keyPress->type(), keyPress->key(), keyPress->modifiers());
-            qApp->postEvent(this, event);
-            return true;
-        } else if (keyPress->key() == Qt::Key_Tab) {
+        if (keyPress->key() == Qt::Key_Tab) {
             m_focusIndex = SearchEdit;
             moveCurrentSelectApp(Qt::Key_Tab);
             return true;
@@ -1160,16 +1165,13 @@ void FullScreenFrame::initConnection()
 
 void FullScreenFrame::showLauncher()
 {
-    scaledBackground();
-    scaledBlurBackground();
-    update();
-
     m_focusIndex = 1;
     m_appItemDelegate->setCurrentIndex(QModelIndex());
 
     // 启动器跟随任务栏位置
     updateGeometry();
 
+    setFocus(Qt::ActiveWindowFocusReason);
     m_searchWidget->categoryBtn()->clearFocus();
     m_searchWidget->edit()->clearEdit();
     m_searchWidget->edit()->clear();
@@ -1178,19 +1180,8 @@ void FullScreenFrame::showLauncher()
 
     m_searchWidget->edit()->lineEdit()->clearFocus();
 
-    if (IconCacheManager::iconLoadState()) {
-        setFixedSize(m_appsManager->currentScreen()->geometry().size());
-        show();
-
-        // 显示后加载当前模式其他ratio的资源，预加载全屏另一种模式当前ratio的资源
-        if (m_calcUtil->displayMode() == GROUP_BY_CATEGORY) {
-            m_appsManager->loadOtherRatioIcon(GROUP_BY_CATEGORY);
-            m_appsManager->loadCurRationIcon(ALL_APPS);
-        } else {
-            m_appsManager->loadOtherRatioIcon(ALL_APPS);
-            m_appsManager->loadCurRationIcon(GROUP_BY_CATEGORY);
-        }
-    }
+    setFixedSize(m_appsManager->currentScreen()->geometry().size());
+    show();
 }
 
 void FullScreenFrame::hideLauncher()
@@ -1787,11 +1778,6 @@ AppsListModel::AppCategory FullScreenFrame::prevCategoryType(const AppsListModel
     return prevCategory;
 }
 
-const QScreen *FullScreenFrame::currentScreen()
-{
-    return m_appsManager->currentScreen();
-}
-
 void FullScreenFrame::layoutChanged()
 {
     QSize boxSize;
