@@ -90,10 +90,6 @@ public:
 
     QStringList calendarSelectIcon() const;
 
-signals:
-     void ratioChanged(double ratio);
-     void loadWindowIcon();
-
 public slots:
     void calculateAppLayout(const QSize &containerSize, const int currentmode);
 
