@@ -26,6 +26,8 @@
 
 class QString;
 class QPoint;
+class MenuWorker;
+class QRect;
 class LauncherInterface
 {
 public:
@@ -37,8 +39,7 @@ public:
     virtual void launchCurrentApp() = 0;
     virtual void appendToSearchEdit(const char ch) = 0;
     virtual void moveCurrentSelectApp(const int key) = 0;
-    virtual void regionMonitorPoint(const QPoint &point) = 0;
-    virtual bool windowDeactiveEvent() = 0;
+    virtual void regionMonitorPoint(const QPoint &point, int flag = 1) = 0;
 
     virtual void uninstallApp(const QString &appKey) = 0;
 };
