@@ -87,11 +87,13 @@ signals:
 
     void itemRedraw(const QModelIndex &index);
 
+    void loadWindowIcon();
     void loadFullWindowIcon();
     void loadCurRationIcon(int mode);
     void loadOtherRatioIcon(int mode);
 
     void startLoadIcon();
+    void loadOtherIcon();
     void loadItem(const ItemInfo &info, const QString &operationStr);
 
 public slots:
