@@ -110,7 +110,7 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     , m_enterSearchEdit(false)
     , m_curScreen(m_appsManager->currentScreen())
 {
-    if (!getDConfigValue("enable-full-screen-mode", true).toBool())
+    if (!getDConfigValue("enableFullScreenMode", true).toBool())
         m_modeToggleBtn->hide();
 
     m_searcherEdit->setAccessibleName("searcherEdit");
@@ -274,6 +274,9 @@ void WindowedFrame::showLauncher()
     if (m_delayHideTimer->isActive())
         return;
 
+    // 显示后加载小窗口其他资源
+    emit m_appsManager->loadOtherIcon();
+
     qApp->processEvents();
     activateWindow();
     setFocus(Qt::ActiveWindowFocusReason);
@@ -290,9 +293,7 @@ void WindowedFrame::showLauncher()
     adjustPosition();
     m_cornerPath = getCornerPath(m_anchoredCornor);
     m_windowHandle.setClipPath(m_cornerPath);
-
-    if (IconCacheManager::iconLoadState())
-        show();
+    show();
 }
 
 void WindowedFrame::hideLauncher()
@@ -557,7 +558,7 @@ void WindowedFrame::uninstallApp(const QModelIndex &context)
     int size = (pixmap.size() / qApp->devicePixelRatio()).width();
     ItemInfo item = context.data(AppsListModel::AppRawItemInfoRole).value<ItemInfo>();
 
-    QPair<QString, int> tmpKey { cacheKey(item, CacheType::ImageType), size};
+    QPair<QString, int> tmpKey { cacheKey(item), size };
 
     // 命令行安装应用后，卸载应用的确认弹框偶现左上角图标呈齿轮的情况
     QPixmap appIcon;
@@ -805,6 +806,11 @@ bool WindowedFrame::eventFilter(QObject *watched, QEvent *event)
             m_searcherEdit->lineEdit()->clearFocus();
     }
 
+    // 窗体变为不活动窗口的时候隐藏launcher
+    if (event->type() == QEvent::WindowDeactivate && watched == this && !QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+        hideLauncher();
+    }
+
     return QWidget::eventFilter(watched, event);
 }
 
