@@ -1,40 +1,35 @@
-#include <gtest/gtest.h>
+#define private public
+#include "blurboxwidget.h"
+#include "appslistmodel.h"
+#undef private
 
 #include <QApplication>
 #include <QWheelEvent>
 
-#include "blurboxwidget.h"
-#include "appslistmodel.h"
-
+#include <gtest/gtest.h>
 
 class Tst_Blurboxwidget : public testing::Test
-{
-public:
-    void SetUp() override
-    {
-        widget = new BlurBoxWidget(AppsListModel::Others, const_cast<char *>("Others"));
-    }
-
-    void TearDown() override
-    {
-        if (widget) {
-            delete widget;
-            widget = nullptr;
-        }
-    }
-
-public:
-    BlurBoxWidget* widget = nullptr;
-};
+{};
 
 TEST_F(Tst_Blurboxwidget, blurBoxWidget_test)
 {
-    widget->setFixedSize(QSize(10, 10));
+    BlurBoxWidget widget(AppsListModel::Others, const_cast<char *>("Others"));
+    widget.setFixedSize(QSize(10, 10));
 
     QMouseEvent event(QEvent::MouseButtonPress, QPointF(0, 0), QPointF(0, 1), QPointF(1, 1), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier, Qt::MouseEventSynthesizedByQt);
-    QApplication::sendEvent(widget, &event);
+    QApplication::sendEvent(&widget, &event);
 
     QMouseEvent event1(QEvent::MouseButtonRelease, QPointF(0, 0), QPointF(0, 1), QPointF(1, 1), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier, Qt::MouseEventSynthesizedByQt);
-    QApplication::sendEvent(widget, &event1);
-}
+    QApplication::sendEvent(&widget, &event1);
 
+    QWidget w;
+    widget.layoutAddWidget(&w, 0, Qt::AlignCenter);
+
+    ASSERT_TRUE(widget.getMultiPagesView());
+
+    QPoint p(0, 0);
+    widget.updateBackBlurPos(p);
+
+    widget.setMaskVisible(false);
+    widget.setMaskVisible(true);
+}
